<?php

namespace Drupal\access_policy;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Provides a listing of AccessPolicy type entities.
 */
interface AccessPolicySelectionInterface {

  /**
   * Get access policies available to the user.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The current entity.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The current logged in user.
   *
   * @return \Drupal\Core\Entity\EntityInterface[]
   *   Array of permitted access policies.
   */
  public function getAllowedAccessPolicies(EntityInterface $entity, AccountInterface $account);

  /**
   * Load the default access policy.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The current entity.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The current logged in user.
   *
   * @return bool|\Drupal\access_policy\Entity\AccessPolicyInterface
   *   The default policy or FALSE if none exists.
   */
  public function getDefaultPolicy(EntityInterface $entity, AccountInterface $account);

}
