<?php

namespace Drupal\access_policy\Plugin\AccessRuleArgument;

use Drupal\access_policy\AccessRuleDefinition;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Plugin\PluginBase;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Base class for access rule argument plugins.
 */
abstract class AccessRuleArgumentPluginBase extends PluginBase implements AccessRuleArgumentPluginInterface, ContainerFactoryPluginInterface {

  use StringTranslationTrait;

  /**
   * The access rule argument configuration.
   *
   * @var array
   */
  protected $configuration;

  /**
   * The access rule definition object.
   *
   * @var \Drupal\access_policy\AccessRuleDefinition
   */
  protected $definition;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configuration = $configuration;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
    );
  }

  /**
   * Initialize the access rule argument.
   *
   * @param \Drupal\access_policy\AccessRuleDefinition $definition
   *   The access rule definition.
   */
  public function initialize(AccessRuleDefinition $definition) {
    $this->definition = $definition;
  }

  /**
   * {@inheritdoc}
   */
  public function valueForm(array $form, FormStateInterface $form_state) {
    return $form;
  }

}
